pub enum DaemonError {
Io {
source: Error,
},
Serialize {
source: Error,
},
Bind {
source: Error,
},
Shutdown,
}Expand description
Transport / lifecycle errors that are not reported to the client as a JSON-RPC error but instead cause the listener or connection loop to abort.
Variants